@@ -128,7 +128,8 @@ create_F <- function(U, B, heterozygous = TRUE) {
 #' @param F_matrix A matrix representing the true VAF values of a series of mutations in a set of samples (F matrix).
 #' @param depth A numeric value representing the mean depth of sequencing.
 #' @param overdispersion A numeric value representing the overdispersion parameter for the negative binomial distribution used to simulate the depth of sequencing.
-#'
+#' @param error_rate A numeric value specifying the mismatch error rate per base. Default is 0.001.
+#' 
 #' @return A matrix containing noisy VAF values of a series of mutations in a set of samples.
 #'
 #' @examples
@@ -148,14 +149,14 @@ create_F <- function(U, B, heterozygous = TRUE) {
 #' noisy_F <- add_noise(F_true, 30, 5)
 #'
 #' @export
-add_noise <- function(F_matrix, depth, overdispersion) {
+add_noise <- function(F_matrix, depth, overdispersion, error_rate=0.001) {
   #warn <- getOption("warn")
   #options(warn=-1)
   depth_values <- purrr::map_dbl(1:length(F_matrix), function(x) stats::rnbinom(n = 1, mu = depth, size = overdispersion))
   alt_allele_counts <- purrr::map_dbl(1:length(F_matrix), function(x) stats::rbinom(n = 1, prob = F_matrix[x], size = depth_values[x]))
   #ref_allele_counts <- map_dbl(1:length(F), function(x) rbinom(n = 1, prob = 1-F[x], size = depth_values[x]))
-  alt_allele_mismatch_counts <- purrr::map_dbl(1:length(F_matrix), function(x) stats::rbinom(n = 1, prob = 0.001, size = alt_allele_counts[x]))
-  ref_to_alt_allele_mismatch_counts <- purrr::map_dbl(1:length(F_matrix), function(x) stats::rbinom(n = 1, prob = 0.001/3, size = depth_values[x] - alt_allele_counts[x])) # aqui en el size no uso ref_allele_counts porque tengo en cuenta q en el sitio puede haber otro alelo y su cambio hacia el alternativo también nos estaría sumando a las reads alternativas
+  alt_allele_mismatch_counts <- purrr::map_dbl(1:length(F_matrix), function(x) stats::rbinom(n = 1, prob = error_rate, size = alt_allele_counts[x]))
+  ref_to_alt_allele_mismatch_counts <- purrr::map_dbl(1:length(F_matrix), function(x) stats::rbinom(n = 1, prob = error_rate/3, size = depth_values[x] - alt_allele_counts[x])) # aqui en el size no uso ref_allele_counts porque tengo en cuenta q en el sitio puede haber otro alelo y su cambio hacia el alternativo también nos estaría sumando a las reads alternativas
   noisy_vafs <- matrix(
     (alt_allele_counts - alt_allele_mismatch_counts + ref_to_alt_allele_mismatch_counts)/depth_values,
     byrow = FALSE, nrow = nrow(F_matrix))
