@@ -199,10 +199,10 @@ combine_trees <- function(phylotree_1, phylotree_2, palette = GeRnika::palettes$
   }
   label <- 'label'
   color <- 'color'
-  color_tree1 <- colorspace::adjust_transparency(palette[1], alpha = 0.25)
-  color_tree2 <- colorspace::adjust_transparency(palette[2], alpha = 0.25)
+  color_tree1 <- colorspace::adjust_transparency(palette[1], alpha = 0.3)
+  color_tree2 <- colorspace::adjust_transparency(palette[2], alpha = 0.3)
   color_combined <- palette[3]
-  not_color <- colorspace::adjust_transparency("black", alpha = 0.2)
+  not_color <- colorspace::adjust_transparency("black", alpha = 0.3)
   tree1 <- data.tree::ToDiagrammeRGraph(data.tree::Clone(phylotree_1@tree))
   tree2 <- data.tree::ToDiagrammeRGraph(data.tree::Clone(phylotree_2@tree))
   if (!(length(phylotree_1@clones)==length(phylotree_2@clones))) {
@@ -224,7 +224,7 @@ combine_trees <- function(phylotree_1, phylotree_2, palette = GeRnika::palettes$
       if(length(intersection) != length(phylotree_1@genes)) {
         tree1 <- DiagrammeR::set_node_attrs_ws(DiagrammeR::invert_selection(DiagrammeR::select_nodes(tree1, conditions=(label %in% intersection))), 
                                     node_attr = 'color', value = not_color)
-        tree1 <- DiagrammeR::set_node_attrs_ws(tree1, node_attr = 'fontcolor', value = "grey")
+        tree1 <- DiagrammeR::set_node_attrs_ws(tree1, node_attr = 'fontcolor', value = not_color)
       }
       inter_edges <- DiagrammeR::get_edge_ids(tree1)[which(DiagrammeR::get_edges(tree1, return_values = "label") 
                                                %in% DiagrammeR::get_edges(tree2, return_values = "label"))]
